summaryrefslogtreecommitdiff
path: root/deva/deva.h
diff options
context:
space:
mode:
authormarcus <marcus>2005-02-01 01:22:38 +0000
committermarcus <marcus>2005-02-01 01:22:38 +0000
commita1f2fa2af10c4b18ccc3af18658b878481dbe25d (patch)
treea5d27d215aaf731609f4201f8945dd7049f606ae /deva/deva.h
parentc7c36eae1fb2e932a0ad0f760b824affddb3beb4 (diff)
2005-02-01 Marcus Brinkmann <marcus@gnu.org>
* deva.h (deva_alloc): Renamed to device_alloc. (deva_class_init): Renamed to device_class_init and add new device type argument. (enum device_type): New enum. * deva.c (create_bootstrap_caps): Call device_alloc, not deva_alloc, and pass device type argument. (main): Call device_class_init, not deva_class_init. * deva-class.c: Removed file. * device.h, device.c, device-console.c: New files. * Makefile.am (deva_SOURCES): Remove deva-class.c and add device.h, device.c, device-console.c.
Diffstat (limited to 'deva/deva.h')
-rw-r--r--deva/deva.h18
1 files changed, 12 insertions, 6 deletions
diff --git a/deva/deva.h b/deva/deva.h
index 6b52fb5..f2a47a5 100644
--- a/deva/deva.h
+++ b/deva/deva.h
@@ -42,11 +42,17 @@ int main (int argc, char *argv[]);
void switch_thread (l4_thread_id_t from, l4_thread_id_t to);
-/* Deva objects. */
+/* Device objects. */
-/* Initialize the task class subsystem. */
-error_t deva_class_init ();
+/* Initialize the device class subsystem. */
+error_t device_class_init ();
-/* Allocate a new deva object. The object returned is locked and has
- one reference. */
-error_t deva_alloc (hurd_cap_obj_t *r_obj);
+enum device_type
+ {
+ DEVICE_CONSOLE = 0,
+ DEVICE_SERIAL = 1
+ };
+
+/* Allocate a new device object. The object returned is locked and
+ has one reference. */
+error_t device_alloc (hurd_cap_obj_t *r_obj, enum device_type type);